@@ -16,6 +16,8 @@ class NextcloudDeckDialog;
 
 class NextcloudDeckDialog : public MasterDialog {
     Q_OBJECT
+   Q_SIGNALS:
+    void searchInNotes(QString text);
 
    public:
     explicit NextcloudDeckDialog(QWidget *parent = nullptr, bool listMode = false);
@@ -59,6 +61,8 @@ class NextcloudDeckDialog : public MasterDialog {
 
     void on_cardItemTreeWidget_customContextMenuRequested(const QPoint &pos);
 
+    void searchLinkInNotes(QTreeWidgetItem *item);
+
    private:
     Ui::NextcloudDeckDialog *ui;
     void setupMainSplitter();
@@ -71,6 +75,7 @@ class NextcloudDeckDialog : public MasterDialog {
     NextcloudDeckService::Card _currentCard;
 
     void openUrlInBrowserForItem(const QTreeWidgetItem *item);
+    void addCardLinkToCurrentNote(const QTreeWidgetItem *item);
 };
 
 #endif    // NEXTCLOUDDECKDIALOG_H
