@@ -51,7 +51,8 @@ void CodeToHtmlConverter::initCodeLangs() Q_DECL_NOTHROW {
         {QStringLiteral("yml"), CodeToHtmlConverter::CodeYAML},
         {QStringLiteral("yaml"), CodeToHtmlConverter::CodeYAML},
         {QStringLiteral("forth"), CodeToHtmlConverter::CodeForth},
-        {QStringLiteral("systemverilog"), CodeToHtmlConverter::CodeSystemVerilog}};
+        {QStringLiteral("systemverilog"), CodeToHtmlConverter::CodeSystemVerilog},
+        {QStringLiteral("gdscript"), CodeToHtmlConverter::CodeGDScript}};
 }
 
 QString CodeToHtmlConverter::process(const QString &input) const {
@@ -160,6 +161,10 @@ QString CodeToHtmlConverter::process(StringView input) const {
         case CodeSystemVerilog:
             loadSystemVerilogData(types, keywords, builtin, literals, others);
             break;
+        case CodeGDScript:
+            loadGDScriptData(types, keywords, builtin, literals, others);
+            comment = QLatin1Char('#');
+            break;
         default:
             output += escapeString(input);
             return output;
