@@ -732,6 +732,10 @@ class MainWindow : public QMainWindow {
 
     void on_actionManage_Nextcloud_Deck_cards_triggered();
 
+    void on_actionSend_clipboard_triggered();
+
+    void on_actionSend_clipboard_as_text_triggered();
+
    public:
     /** Settings access **/
     static bool isInDistractionFreeMode();
