@@ -20,6 +20,7 @@
 #include "mainwindow.h"
 #include "owncloudservice.h"
 #include "services/settingsservice.h"
+#include "services/websocketserverservice.h"
 
 DatabaseService::DatabaseService() = default;
 
@@ -878,15 +879,15 @@ bool DatabaseService::setupTables() {
     }
 
     if (version < 40) {
-        const auto bookmarksNoteName =
-            settings.value(QStringLiteral("webSocketServerService/bookmarksNoteName")).toString();
+#ifndef INTEGRATION_TESTS
+        const auto bookmarksNoteName = WebSocketServerService::getBookmarksNoteName();
 
         // fix overwritten bookmarksNoteName
         if (bookmarksNoteName == QStringLiteral("Commands")) {
             settings.setValue(QStringLiteral("webSocketServerService/bookmarksNoteName"),
                               QStringLiteral("Bookmarks"));
         }
-
+#endif
         version = 40;
     }
 
