@@ -18,6 +18,7 @@
 #include <QSslError>
 #include <QTimer>
 
+class QClipboard;
 class QWebSocket;
 class QSslError;
 class QString;
@@ -25,6 +26,7 @@ class QString;
 class WebAppClientService : public QObject {
     Q_OBJECT
    public:
+    void initClipboardService();
     explicit WebAppClientService(QObject *parent = nullptr);
     ~WebAppClientService() override;
 
@@ -33,6 +35,8 @@ class WebAppClientService : public QObject {
     static QString getOrGenerateToken();
     void open();
     void close();
+    bool sendClipboard() const;
+    bool sendClipboardAsText() const;
 
    private slots:
     void onConnected();
@@ -44,6 +48,9 @@ class WebAppClientService : public QObject {
 
    private:
     QWebSocket *_webSocket{};
+    QString _clipboardMimeType;
+    QString _clipboardContent;
+    QString _clipboardTextContent;
     QString _url;
     const int _heartbeatTime = 600000;    // heartbeat data transmission time interval in ms
     const int _reconnectHeartbeatTimerCount =
@@ -53,4 +60,10 @@ class WebAppClientService : public QObject {
     int _reconnectFailedCount = 0;       // reconnection failures
     QTimer _timerHeartbeat;              // send heartbeat timer
     QTimer _timerReconnect;              // reconnection timer
+    QString _heartbeatText;
+    QString _sessionId;
+
+    void generateSessionId();
+    void sendInsertIntoClipboard(const QString &mimeType, const QString &content) const;
+    bool keepClipboard();
 };
