@@ -20,6 +20,7 @@
 #include "helpers/qownspellchecker.h"
 #include "libraries/qmarkdowntextedit/linenumberarea.h"
 #include "mainwindow.h"
+#include "services/nextclouddeckservice.h"
 #include "services/scriptingservice.h"
 #include "services/settingsservice.h"
 #include "utils/urlhandler.h"
@@ -29,7 +30,7 @@ QOwnNotesMarkdownTextEdit::QOwnNotesMarkdownTextEdit(QWidget *parent)
     // We need to set the internal variable to true, because we start with a highlighter
     _highlightingEnabled = true;
     _highlighter = nullptr;
-    if (parent->objectName() != QStringLiteral("LogWidget")) {
+    if (!parent || parent->objectName() != QStringLiteral("LogWidget")) {
         _highlighter = new QOwnNotesMarkdownHighlighter(document());
 
         setStyles();
@@ -1203,3 +1204,14 @@ bool QOwnNotesMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
 
     return QMarkdownTextEdit::eventFilter(obj, event);
 }
+
+void QOwnNotesMarkdownTextEdit::updateIgnoredClickUrlRegexps() {
+    NextcloudDeckService nextcloudDeckService(this);
+
+    if (nextcloudDeckService.isEnabledAndValid()) {
+        QList<QRegularExpression> ignoredClickUrlRegexps;
+        ignoredClickUrlRegexps.append(QRegularExpression(
+            QRegularExpression::escape(nextcloudDeckService.getCardUrlPattern())));
+        setIgnoredClickUrlRegexps(ignoredClickUrlRegexps);
+    }
+}
